==> cuenca_validations-0.7.7.dev11.tar.gz: cuenca_validations-0.7.7.dev11/cuenca_validations/errors.py <==
__all__ = ['CardBinValidationError', 'NotDigitError']

from pydantic.errors import (
    NotDigitError as PydanticNotDigitError,
    PydanticValueError,
)


class CardBinValidationError(PydanticValueError):
    code = 'payment_card_number.bin'
    msg_template = (
        'The card number contains a BIN (first six digits) that does not have'
        'a known association with a Mexican bank. To add the association,'
        'please file an issue:'
        'https://github.com/cuenca-mx/cuenca-validations/issues'
    )


class NotDigitError(PydanticNotDigitError):
    code = 'digits'
    msg_template = 'value is not all digits'


class AuthedException(Exception):
    """Exceptions related to ApiKeys, Login, Password, etc"""

    code: int
    status_code: int


class WrongCreds(AuthedException):
    """Invalid ApiKeys"""

    code = 101
    status_code = 401


class MissingAuthorizationHeader(AuthedException):
    """Neither Basic Auth or JWT found"""

    code = 102
    status_code = 401


class UserNotLoggedIn(AuthedException):
    """Login required for this method"""

    code = 103
    status_code = 401


class NoPasswordFound(AuthedException):
    """User must create a password before to continue"""

    code = 104
    status_code = 401


class AuthMethodNotAllowed(AuthedException):
    """No permissions to use this authentication method"""

    code = 105
    status_code = 401


AUTHED_ERROR_CODES = {
    exc.code: exc
    for exc in [
        WrongCreds,
        MissingAuthorizationHeader,
        UserNotLoggedIn,
        NoPasswordFound,
        AuthMethodNotAllowed,
    ]
}

==> cuenca_validations-0.9.14.dev10.tar.gz: cuenca_validations-0.9.14.dev10/cuenca_validations/errors.py <==
__all__ = ['CardBinValidationError', 'NotDigitError']

from pydantic.errors import (
    NotDigitError as PydanticNotDigitError,
    PydanticValueError,
)


class CardBinValidationError(PydanticValueError):
    code = 'payment_card_number.bin'
    msg_template = (
        'The card number contains a BIN (first six digits) that does not have'
        'a known association with a Mexican bank. To add the association,'
        'please file an issue:'
        'https://github.com/cuenca-mx/cuenca-validations/issues'
    )


class NotDigitError(PydanticNotDigitError):
    code = 'digits'
    msg_template = 'value is not all digits'


class CuencaError(Exception):
    """Exceptions related to ApiKeys, Login, Password, etc"""

    code: int
    status_code: int


class WrongCredsError(CuencaError):
    """Invalid ApiKeys"""

    code = 101
    status_code = 401


class MissingAuthorizationHeaderError(CuencaError):
    """Neither Basic Auth or JWT found"""

    code = 102
    status_code = 401


class UserNotLoggedInError(CuencaError):
    """Login required for this method"""

    code = 103
    status_code = 401


class NoPasswordFoundError(CuencaError):
    """User must create a password before to continue"""

    code = 104
    status_code = 401


class AuthMethodNotAllowedError(CuencaError):
    """No permissions to use this authentication method"""

    code = 106
    status_code = 401


class TooManyAttemptsError(CuencaError):
    """This user has tried too many times to activate a card"""

    code = 107
    status_code = 403


ERROR_CODES = {
    exc.code: exc
    for exc in [
        WrongCredsError,
        MissingAuthorizationHeaderError,
        UserNotLoggedInError,
        NoPasswordFoundError,
        AuthMethodNotAllowedError,
        TooManyAttemptsError,
    ]
}
